﻿using ReportingServices.HelperClasses;
using ReportingServices.ReportingObjects;

namespace ReportingServices.Models.ProductionReport
{
    public class DailyReport
    {
        public DateTime StartDate { get; set; }
        public YieldStatistics CurrentWeek { get; set; }
        public YieldStatistics PreviousWeek { get; set; }
        public Dictionary<string, List<EquipmentStateByDay>> ToolAvailibilityByType { get; set; }
        public Dictionary<string, ToolStateByType> ToolStateByType { get; set; }
        public Dictionary<string, List<string>> ToolStatesByOwner { get; set; }
        public Dictionary<string, List<string>> DualLayerReactors { get; set; }
        public List<ManualReportEntries> PreviousEntries { get; set; }
        public List<ManualReportEntries> CurrentEntries { get; set; }
        public int NumberOfToolsWaferSize6IN { get; set; }
        public int NumberOfToolsWaferSize8IN { get; set; }
        public int NumberOfToolsWaferSize6INScheduled { get; set; }
        public int NumberOfToolsWaferSize8INScheduled { get; set; }
        public QuarterlyTargets QuarterlyTargets { get; set; }

        public DailyReport()
        {
            ToolAvailibilityByType = new();
            ToolStateByType = new();
            PreviousEntries = new();
            CurrentEntries = new();
            StartDate = DateTime.Parse(APIHelperFunctions.GetBeginningOfWeekAsAPIString());
            CurrentWeek = new(StartDate, true);
            PreviousWeek = new(StartDate.AddDays(-7), false);
        }

        public void AddToolAvailibilityByType(string key, List<EquipmentStateByDay> states)
        {
            ToolAvailibilityByType.Add(key, states);
        }

        public void AddToolStateByType(string key, List<ToolStateCurrent> states)
        {
            ToolStateByType state = new(states);

            ToolStateByType.Add(key, state);
        }

        public void ReverseLists()
        {
            CurrentWeek.ScrapByDay = APIHelperFunctions.ReverseList(CurrentWeek.ScrapByDay);
            PreviousWeek.ScrapByDay = APIHelperFunctions.ReverseList(PreviousWeek.ScrapByDay);

            ToolAvailibilityByType["ASM"] = APIHelperFunctions.ReverseList(ToolAvailibilityByType["ASM"]);
            ToolAvailibilityByType["EPP"] = APIHelperFunctions.ReverseList(ToolAvailibilityByType["EPP"]);
            ToolAvailibilityByType["HTR"] = APIHelperFunctions.ReverseList(ToolAvailibilityByType["HTR"]);
        }
    }
}
